/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Xóa"

, "Reply"
: "Trả lời"

, "Reply To All"
: "Trả lời tất cả"

, "Forward"
: "Chuyển tiếp"

, "Print Message"
: "In nội dung"

, "Print Preview"
: "Xem trước khi in"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "one: Trả lời tự động\nother: Trả lời tự động"

]
, "Account, Accounts"
: [
  "one: Tài khoản\nother: Tài khoản"

]
, "Account Name"
: "Tên tài khoản"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Email người dùng"

, "User Name (From)"
: "Tên người dùng (Từ)"

, "Organization"
: "Tổ chức"

, "Signature position"
: "Vị trí chữ ký"

, "Above the quote"
: "Trên trích dẫn"

, "Below the quote"
: "Dưới trích dẫn"

, "IMAP"
: "IMAP"

, "Host"
: "Host"

, "Port (Default: 143 / SSL: 993)"
: "Port (Default: 143 / SSL: 993)"

, "Secure Connection"
: "Kết nối bảo mật"

, "None"
: "Không"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Tên đăng nhập"

, "Password"
: "Mật khẩu"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (Default: 25)"

, "Authentication"
: "Authentication"

, "Login"
: "Đăng nhập"

, "Plain"
: "Thuần"

, "Username (optional)"
: "Tên truy cập (tùy chọn)"

, "Password (optional)"
: "Mật khẩu (tùy chọn)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Sieve"

, "Port (Default: 2000)"
: "Port (Default: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Thiết lập khác"

, "Sent Folder Name"
: "Tên thư mục Đã gửi"

, "Trash Folder Name"
: "Tên thư mục Thùng rác"

, "Drafts Folder Name"
: "Tên thư mục Nháp"

, "Templates Folder Name"
: "Tên thư mục Biểu mẫu"

, "Display Format"
: "Định dạng hiển thị"

, "HTML"
: "HTML"

, "Plain Text"
: "Thuần văn bản"

, "Depending on content type (experimental)"
: "Phụ thuộc vào kiểu nội dung (kinh nghiệm)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Soạn thư"

, "Toggle highlighting"
: "Bật tắt điểm nhấn"

, "Mark read/unread"
: "Đánh dấu đọc/chưa đọc"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Thêm tài khoản"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "ID"

, "Attachments"
: "Đính kèm"

, "Flags"
: "Cờ"

, "Subject"
: "Tiêu đề"

, "From (Email)"
: "Từ (email)"

, "From (Name)"
: "Từ (tên)"

, "Sender"
: "Người gửi"

, "To"
: "Tới"

, "Sent"
: "Đã gửi"

, "Received"
: "Đã nhận"

, "Folder, Folders"
: [
  "one:Thư mục\nother:Thư mục"

]
, "Size"
: "Dung lượng"

, "Answered"
: "Đã trả lời"

, "Forwarded"
: "Đã chuyển tiếp"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "Gửi xác nhận đã đọc"

, "Do you want to send a reading confirmation message?"
: ""

, "Empty Folder"
: "Thư mục rỗng"

, "Add Folder"
: "Thêm thư mục"

, "New {0}"
: "Tạo {0}"

, "Please enter the name of the new {0}:"
: "Xin nhập tên của {0} mới:"

, "No {0} added"
: "Không {0} được thêm"

, "You have to supply a {0} name!"
: "Bạn phải cung cấp 1 tên {0}"

, "Please wait"
: "Xin đợi"

, "Creating {0}..."
: "Đang tạo {0} ..."

, "Edit Account"
: "Sửa tài khoản"

, "Edit Vacation Message"
: "Sửa nội dung trả lời tự động"

, "Edit Filter Rules"
: "Sửa quy tắc bộ lọc"

, "Notifications"
: ""

, "Mark Folder as read"
: "Đánh dấu thư mục như đã đọc"

, "Update Folder List"
: "Cập nhật danh sách thư mục"

, "Message not available."
: "Nội dung không sẵn sàng"

, "Cancel"
: "Hủy bỏ"

, "Ok"
: "OK"

, "Folders of account {0}"
: "Thư mục của tài khoản {0}"

, "Folders of all accounts"
: "Thư mục của mọi tài khoản"

, "Compose email"
: "Soạn Email"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "Từ"

, "Add"
: "Thêm"

, "Add contact to addressbook"
: "Thêm liên lạc vào sổ địa chỉ"

, "Date"
: "Ngày"

, "Show or hide header information"
: "Hiện/ ẩn thông tin header"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(thư mới)"

, "Select recipients for \"{0}\""
: "Chọn người nhận cho \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Bộ lọc người nhận"

, "All recipients"
: "Mọi người nhận"

, "\"{0}\" recipients"
: "\"{0}\" người nhận"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Nội dung trả lời tự động cho {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Chuyển lên"

, "Move down"
: "Chuyển xuống"

, "Enable"
: "Mở"

, "Disable"
: "Tắt"

, "ID"
: "ID"

, "Conditions"
: "Điều kiện"

, "Action"
: "Hành động"

, "Keep a copy"
: ""

, "is greater than"
: "lớn hơn"

, "is less than"
: "nhỏ hơn"

, "Header \"{0}\" contains \"{1}\""
: "Header \"{0}\" contains \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Header \"{0}\" matches \"{1}\""

, "Sieve Filter Rules"
: "Quy tắc lọc Sieve"

, "Sieve Filter Rules for {0}"
: "Quy tắc lọc Sieve cho {0}"

, "From (Email and Name)"
: "Từ (Email và Tên)"

, "To (Email)"
: "To (Email)"

, "To (Email CC)"
: ""

, "Header contains"
: "Chứa header"

, "Header name"
: "Tên header"

, "Header value"
: "Giá trị Header"

, "Header regex"
: "Header regex"

, "Edit Filter Rule"
: "Sửa quy tắc lọc"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Thực hiện hành động:"

, "Move mail to folder"
: "Chuyển thư tới thư mục"

, "Redirect mail to address"
: "Chuyển hướng tới địa chỉ"

, "Reject mail with this text"
: "R"

, "Discard mail"
: "Hủy thư"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Giữ email"

, "General"
: "Chung"

, "Advanced"
: "Nâng cao"

, "Only send all X days to the same sender"
: "Chỉ gửi mọi thư X ngày tới cùng người gửi"

, "Incoming mails will be answered with this text:"
: "Thư đến sẽ được trả lời với đoạn văn bản sau:"

, "Status"
: "Trạng thái"

, "I am available (vacation message disabled)"
: "Tôi sẵn sàng (nội dung trả lời tự động tắt)"

, "I am not available (vacation message enabled)"
: "Tôi không sẵn sàng (nội dung trả lời tự động mở)"

, "Start Date"
: "Ngày bắt đầu"

, "Set vacation start date ..."
: "Đặt ngày trả lời tự động..."

, "End Date"
: "Ngày kết thúc"

, "Set vacation end date ..."
: "Đặt ngày kết thúc trả lời tự động..."

, "Representative #1"
: "Representative #1"

, "Choose first Representative ..."
: "Choose first Representative ..."

, "Representative #2"
: "Representative #2"

, "Choose second Representative ..."
: "Choose second Representative ..."

, "Message Template"
: "Mẫu nội dung"

, "Choose Template ..."
: "Chọn mẫu..."

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "one: Nội dung\nother: Nội dung"

]
, "Subject/From"
: "Tiêu đề/Từ"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "Thư đến"

, "Drafts"
: "Nháp"

, "Templates"
: "Mẫu"

, "Junk"
: "Thư rác"

, "Trash"
: "Thùng rác"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "one: danh sách biểu ghi\nother: danh sách biểu ghi"

]
, "Rule, Rules"
: [
  "one: Quy tắc\nother: Quy tắc"

]
, "Flag, Flags"
: [
  "one:Cờ\nother:Cờ"

]
, "Flag list, Flag lists"
: [
  "one:Danh sách cờ\nother:Danh sách cờ"

]
, "Total Messages:"
: "Tổng số tin nhắn"

, "Unread Messages:"
: "Thư chưa đọc:"

, "Name on Server:"
: "Tên trên máy chủ:"

, "Last update:"
: "Cập nhật lần cuối:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"

]
, "New Mail"
: "Email mới"

, "Email"
: "Email"

, "Active Vacation Message"
: "Bật chế độ tự động trả lời"

, "Email account \"{0}\" has an active vacation message."
: "Tài khoản email \"{0}\" có 1 email tự động trả lời đang hoạt động"

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Email mới"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Bạn có {0} email mới trong thư mục {1} ({2})."

, "IMAP Credentials for {0}"
: "IMAP Credentials for {0}"

, "Credentials"
: "Credentials"

, "IMAP Error"
: "IMAP Error"

, "No connection to IMAP server."
: "Không kết nối tới máy chủ IMAP"

, "IMAP Credentials Error"
: "IMAP Credentials Error"

, "Your email credentials are wrong. Please contact your administrator"
: "Thông tin email bị sai. Xin hãy liên lạc với quản trị hệ thống của bạn."

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Một trong số thư mục của bạn đã bị xóa hoặc đổi tên bởi người dùng khác."

, "SMTP Error"
: "SMTP Error"

, "No connection to SMTP server."
: "Không có kết nối tới máy chủ SMTP"

, "Sieve Error"
: "Sieve Error"

, "No connection to Sieve server."
: "Không có kết nối tới máy chủ Sieve"

, "Save Sieve Script Error"
: "Lưu lỗi Sieve Script"

, "Could not save script on Sieve server."
: "Không thể lưu scrip trên máy chủ Sieve"

, "Add as \"To\""
: "Thêm vào \"Đến\""

, "Add as \"Cc\""
: "Thêm \"CC\""

, "Add as \"Bcc\""
: "Thêm \"BCC\""

, "Remove from recipients"
: "Xóa khỏi người nhận"

, "Loading Mail Addresses"
: "Đang tải địa chỉ email"

, "Click here to set To/CC/BCC."
: "Click vào đây để đặt To/CC/BCC"

, "To:"
: "To:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Xóa"

, "Send"
: "Gửi"

, "Search Recipients"
: "Tìm người nhận"

, "Save As Draft"
: "Lưu bản nháp"

, "Save As Template"
: "Lưu thành mẫu"

, "Reading Confirmation"
: "Xác nhận đã đọc"

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Click để tìm kiếm và thêm người nhận từ danh bạ"

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Fwd:"

, "{0} Message"
: "Nội dung {0}"

, "Failed"
: "Thất bại"

, "{0} account setting empty."
: "{0} thiết lập tài khoản rỗng."

, "Files are still uploading."
: "Files vẫn đang được upload."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "Vào {0}, {1} viết"

, "Original message"
: "Nội dung gốc"

, "Compose email:"
: "Soạn email:"

, "Convert to formated text"
: ""

, "Body"
: "Nội dung"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Tiêu đề trống"

, "Do you really want to send a message with an empty subject?"
: "Bạn có muốn gửi 1 email với tiêu đề trống?"

, "No recipients set."
: "Không chỉ ra người nhận."

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Mọi thư đến"

, "Default Email Account"
: "Tài khoản email mặc định"

, "The default email account to use when sending mails."
: "Tài khoản email mặc định được dùng khi gửi email"

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Khoảng thời gian cập nhật email"

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Sử dụng cho GHI CHÉP"

, "Save Note default Value."
: "Lưu giá trị ghi chép mặc định "

, "Confirm Delete"
: "Xác nhận xóa"

, "Show confirmation dialog when deleting mails."
: "Hiển thị cửa sổ xác nhận khi xóa thư."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Nội dung trả lời tự động"

, "User is allowed to set custom vacation message for system account"
: "Người dùng được phép đặt nội dung trả lời tự động theo ý muốn cho tài khoản hệ thống"

, "Cache email body"
: "Bản lưu đệm nội dung email"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Should the email body be cached (recommended for slow IMAP server connections)"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "Xác nhận đã đọc"

, "Your message:"
: "Nội dung của bạn"

, "Received on"
: ""

, "Was read by:"
: "Đã đọc bởi"

, "on"
: "vào"

, "Message File Location, Message File Locations"
: [
  ""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Trả lời bên ngoài cơ quan từ %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: "Lỗi: %s"

, "Could not send message"
: "Không thể gửi message"

, "My Mail Download Links"
: ""

, "Seen"
: "Đã xem"

, "Deleted"
: "Đã xóa"

, "Draft"
: "Nháp"

, "Flagged"
: "Đã cắm cờ"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Mọi thư đến trong tài khoản email của tôi."

, "All unread mail"
: "Mọi thư chưa đọc"

, "All unread mail of my email accounts"
: "Mọi email chưa đọc trong tài khoản email của tôi"

, "All highlighted mail"
: "Mọi thư được nhấn mạnh"

, "All highlighted mail of my email accounts"
: "Mọi thư nhấn mạnh trong tài khoản email của tôi"

, "All drafts"
: "Mọi bản nháp"

, "All mails with the draft flag"
: "Mọi thư với cờ nháp"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "quản lý tài khoản email"

, "Edit and delete email accounts"
: "Sửa và xóa tài khoản email"

, "Add email accounts"
: "Thêm tài khoản email"

, "Create new email accounts"
: "Tạo tài khoản email"

, "Vacation"
: "one: Trả lời tự động\nother: Trả lời tự động"

, "Account"
: "one: Tài khoản\nother: Tài khoản"

, "Folder"
: "one:Thư mục\nother:Thư mục"

, "Message"
: "one: Nội dung\nother: Nội dung"

, "record list"
: "one: danh sách biểu ghi\nother: danh sách biểu ghi"

, "Rule"
: "one: Quy tắc\nother: Quy tắc"

, "Flag"
: "one:Cờ\nother:Cờ"

, "Flag list"
: "one:Danh sách cờ\nother:Danh sách cờ"

, "{0} unread message"
: "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
